import { ValidationError, ValidationErrorPath, Validator } from "../interfaces";
import { JSONSchema7 } from "json-schema";
declare type TupleValidators<T extends Array<unknown>> = {
    [K in keyof T]: Validator<T[K]>;
};
interface TupleValidatorOptions<TTuple extends Array<unknown>> {
    readonly validators: TupleValidators<TTuple>;
}
/**
 * Returns a validator that checks the value is a tuple, i.e. an array with a fixed number of elements that match the
 * given validators.
 */
export default class TupleValidator<TTuple extends Array<unknown>> extends Validator<TTuple> {
    private readonly options;
    constructor(options: TupleValidatorOptions<TTuple>);
    validate(value: unknown, path?: ValidationErrorPath): ValidationError[];
    isValid(value: unknown): value is TTuple;
    _toJsonSchema(): JSONSchema7;
}
export {};
